==> sped-1.35.26.tar.gz: sped-1.35.26/pythonsped/efd/layout_15.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2021 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2021, Creative Commons
Autor - Tiago Henrique Prates dos Santos <tiago.santos[at]siginformatica.com.br>
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
import layout_14
from layout_14 import bloco_c as efd_bloco_c
from layout_14 import bloco_1 as efd_bloco_1
from pythonsped.utils import TrackedAttributesClass

# Ato COTEPE/ICMS item 3.1.1 - Tabela Versao do Leiaute
_obrigatoriedade_ = '01/01/2021'
_codigo_ = '015'  # layout_15
_versao_ = '114'


class bloco_0(layout_14.bloco_0):
    pass


class bloco_1(efd_bloco_1):


    class registro_1250(TrackedAttributesClass):
        """
        REGISTRO 1250: INFORMAÇÕES CONSOLIDADAS DE SALDOS DE RESTITUIÇÃO, RESSARCIMENTO E
        COMPLEMENTAÇÃO DO ICMS
        """
        _order = []

        def __init__(self):
            super(bloco_1.registro_1250, self).__init__()
            self.REG = '1250'
            self.nivel_h = 2  # nível
            self.pai = '1010'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.VL_CREDITO_ICMS_OP = ''
            self.VL_ICMS_ST_REST = ''
            self.VL_FCP_ST_REST = ''
            self.VL_ICMS_ST_COMPL = ''
            self.VL_FCP_ST_COMPL = ''
            self.fieldnames = ('REG', 'VL_CREDITO_ICMS_OP', 'VL_ICMS_ST_REST', 'VL_FCP_ST_REST',
                               'VL_ICMS_ST_COMPL', 'VL_FCP_ST_COMPL')
            self.formato = self.get_formato()


    class registro_1255(TrackedAttributesClass):
        """
        INFORMAÇÕES CONSOLIDADAS DE SALDOS DE RESTITUIÇÃO, RESSARCIMENTO E COMPLEMENTAÇÃO DO ICMS
        POR MOTIVO
        """
        _order = []

        def __init__(self):
            super(bloco_1.registro_1255, self).__init__()
            self.REG = '1255'
            self.nivel_h = 3  # nível
            self.pai = '1250'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOT_REST_COMPL = ''
            self.VL_CREDITO_ICMS_OP_MOT = ''
            self.VL_ICMS_ST_REST_MOT = ''
            self.VL_FCP_ST_REST_MOT = ''
            self.VL_ICMS_ST_COMPL_MOT = ''
            self.VL_FCP_ST_COMPL_MOT = ''
            self.fieldnames = ('REG', 'COD_MOT_REST_COMPL', 'VL_CREDITO_ICMS_OP_MOT',
                               'VL_ICMS_ST_REST_MOT', 'VL_FCP_ST_REST_MOT', 'VL_ICMS_ST_COMPL_MOT',
                               'VL_FCP_ST_COMPL_MOT')
            self.formato = self.get_formato()


class bloco_c(efd_bloco_c):


    class registro_C181(TrackedAttributesClass):
        """
        REGISTRO C181: INFORMAÇÕES COMPLEMENTARES DAS OPERAÇÕES DE DEVOLUÇÃO DE SAÍDAS DE
        MERCADORIAS SUJEITAS À SUBSTITUIÇÃO TRIBUTÁRIA (CÓDIGO 01, 1B, 04 e 55).
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C181, self).__init__()
            self.REG = 'C181'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C100'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOT_REST_COMPL = ''
            self.QUANT_CONV = ''
            self.UNID = ''
            self.COD_MOD_SAIDA = ''
            self.SERIE_SAIDA = ''
            self.ECF_FAB_SAIDA = ''
            self.NUM_DOC_SAIDA = ''
            self.CHV_DFE_SAIDA = ''
            self.DT_DOC_SAIDA = ''
            self.NUM_ITEM_SAIDA = ''
            self.VL_UNIT_CONV_SAIDA = ''
            self.VL_UNIT_ICMS_OP_ESTOQUE_CONV_SAIDA = ''
            self.VL_UNIT_ICMS_ST_ESTOQUE_CONV_SAIDA = ''
            self.VL_UNIT_FCP_ICMS_ST_ESTOQUE_CONV_SAIDA = ''
            self.VL_UNIT_ICMS_NA_OPERACAO_CONV_SAIDA = ''
            self.VL_UNIT_ICMS_OP_CONV_SAIDA = ''
            self.VL_UNIT_ICMS_ST_CONV_REST = ''
            self.VL_UNIT_FCP_ST_CONV_REST = ''
            self.VL_UNIT_ICMS_ST_CONV_COMPL = ''
            self.VL_UNIT_FCP_ST_CONV_COMPL = ''
            self.fieldnames = ('REG', 'COD_MOT_REST_COMPL', 'QUANT_CONV', 'UNID', 'COD_MOD_SAIDA',
                               'SERIE_SAIDA', 'ECF_FAB_SAIDA', 'NUM_DOC_SAIDA', 'CHV_DFE_SAIDA',
                               'DT_DOC_SAIDA', 'NUM_ITEM_SAIDA', 'VL_UNIT_CONV_SAIDA',
                               'VL_UNIT_ICMS_OP_ESTOQUE_CONV_SAIDA',
                               'VL_UNIT_ICMS_ST_ESTOQUE_CONV_SAIDA',
                               'VL_UNIT_FCP_ICMS_ST_ESTOQUE_CONV_SAIDA',
                               'VL_UNIT_ICMS_NA_OPERACAO_CONV_SAIDA', 'VL_UNIT_ICMS_OP_CONV_SAIDA',
                               'VL_UNIT_ICMS_ST_CONV_REST', 'VL_UNIT_FCP_ST_CONV_REST',
                               'VL_UNIT_ICMS_ST_CONV_COMPL', 'VL_UNIT_FCP_ST_CONV_COMPL')
            self.formato = self.get_formato()


    class registro_C186(TrackedAttributesClass):
        """
        REGISTRO C186: INFORMAÇÕES COMPLEMENTARES DAS OPERAÇÕES DE DEVOLUÇÃO DE ENTRADAS DE
        MERCADORIAS SUJEITAS À SUBSTITUIÇÃO TRIBUTÁRIA (CÓDIGO 01, 1B, 04 e 55).
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C186, self).__init__()
            self.REG = 'C186'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C100'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_ITEM = ''
            self.COD_ITEM = ''
            self.CST_ICMS = ''
            self.CFOP = ''
            self.COD_MOT_REST_COMPL = ''
            self.QUANT_CONV = ''
            self.UNID = ''
            self.COD_MOD_ENTRADA = ''
            self.SERIE_ENTRADA = ''
            self.NUM_DOC_ENTRADA = ''
            self.CHV_DFE_ENTRADA = ''
            self.DT_DOC_ENTRADA = ''
            self.NUM_ITEM_ENTRADA = ''
            self.VL_UNIT_CONV_ENTRADA = ''
            self.VL_UNIT_ICMS_OP_CONV_ENTRADA = ''
            self.VL_UNIT_BC_ICMS_ST_CONV_ENTRADA = ''
            self.VL_UNIT_ICMS_ST_CONV_ENTRADA = ''
            self.VL_UNIT_FCP_ST_CONV_ENTRADA = ''
            self.fieldnames = ('REG', 'NUM_ITEM', 'COD_ITEM', 'CST_ICMS', 'CFOP',
                               'COD_MOT_REST_COMPL', 'QUANT_CONV', 'UNID', 'COD_MOD_ENTRADA',
                               'SERIE_ENTRADA', 'NUM_DOC_ENTRADA', 'CHV_DFE_ENTRADA',
                               'DT_DOC_ENTRADA', 'NUM_ITEM_ENTRADA', 'VL_UNIT_CONV_ENTRADA',
                               'VL_UNIT_ICMS_OP_CONV_ENTRADA', 'VL_UNIT_BC_ICMS_ST_CONV_ENTRADA',
                               'VL_UNIT_ICMS_ST_CONV_ENTRADA', 'VL_UNIT_FCP_ST_CONV_ENTRADA')
            self.formato = self.get_formato()


class bloco_e(layout_14.bloco_e):
    pass


class bloco_g(layout_14.bloco_g):
    pass

==> sped-3.0.3.tar.gz: sped-3.0.3/pythonsped/efd/layout_15.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2021 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2021, Creative Commons
Autor - Tiago Henrique Prates dos Santos <tiago.santos[at]siginformatica.com.br>
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from . import layout_14
from .layout_14 import bloco_c as efd_bloco_c
from .layout_14 import bloco_1 as efd_bloco_1
from ..utils import TrackedAttributesClass

# Ato COTEPE/ICMS item 3.1.1 - Tabela Versao do Leiaute
_obrigatoriedade_ = '01/01/2021'
_codigo_ = '015'  # layout_15
_versao_ = '114'


class bloco_0(layout_14.bloco_0):
    pass


class bloco_1(efd_bloco_1):


    class registro_1250(TrackedAttributesClass):
        """
        REGISTRO 1250: INFORMAÇÕES CONSOLIDADAS DE SALDOS DE RESTITUIÇÃO, RESSARCIMENTO E
        COMPLEMENTAÇÃO DO ICMS
        """
        _order = []

        def __init__(self):
            super(bloco_1.registro_1250, self).__init__()
            self.REG = '1250'
            self.nivel_h = 2  # nível
            self.pai = '1010'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.VL_CREDITO_ICMS_OP = ''
            self.VL_ICMS_ST_REST = ''
            self.VL_FCP_ST_REST = ''
            self.VL_ICMS_ST_COMPL = ''
            self.VL_FCP_ST_COMPL = ''
            self.fieldnames = ('REG', 'VL_CREDITO_ICMS_OP', 'VL_ICMS_ST_REST', 'VL_FCP_ST_REST',
                               'VL_ICMS_ST_COMPL', 'VL_FCP_ST_COMPL')
            self.formato = self.get_formato()


    class registro_1255(TrackedAttributesClass):
        """
        INFORMAÇÕES CONSOLIDADAS DE SALDOS DE RESTITUIÇÃO, RESSARCIMENTO E COMPLEMENTAÇÃO DO ICMS
        POR MOTIVO
        """
        _order = []

        def __init__(self):
            super(bloco_1.registro_1255, self).__init__()
            self.REG = '1255'
            self.nivel_h = 3  # nível
            self.pai = '1250'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOT_REST_COMPL = ''
            self.VL_CREDITO_ICMS_OP_MOT = ''
            self.VL_ICMS_ST_REST_MOT = ''
            self.VL_FCP_ST_REST_MOT = ''
            self.VL_ICMS_ST_COMPL_MOT = ''
            self.VL_FCP_ST_COMPL_MOT = ''
            self.fieldnames = ('REG', 'COD_MOT_REST_COMPL', 'VL_CREDITO_ICMS_OP_MOT',
                               'VL_ICMS_ST_REST_MOT', 'VL_FCP_ST_REST_MOT', 'VL_ICMS_ST_COMPL_MOT',
                               'VL_FCP_ST_COMPL_MOT')
            self.formato = self.get_formato()


class bloco_c(efd_bloco_c):


    class registro_C181(TrackedAttributesClass):
        """
        REGISTRO C181: INFORMAÇÕES COMPLEMENTARES DAS OPERAÇÕES DE DEVOLUÇÃO DE SAÍDAS DE
        MERCADORIAS SUJEITAS À SUBSTITUIÇÃO TRIBUTÁRIA (CÓDIGO 01, 1B, 04 e 55).
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C181, self).__init__()
            self.REG = 'C181'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C100'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOT_REST_COMPL = ''
            self.QUANT_CONV = ''
            self.UNID = ''
            self.COD_MOD_SAIDA = ''
            self.SERIE_SAIDA = ''
            self.ECF_FAB_SAIDA = ''
            self.NUM_DOC_SAIDA = ''
            self.CHV_DFE_SAIDA = ''
            self.DT_DOC_SAIDA = ''
            self.NUM_ITEM_SAIDA = ''
            self.VL_UNIT_CONV_SAIDA = ''
            self.VL_UNIT_ICMS_OP_ESTOQUE_CONV_SAIDA = ''
            self.VL_UNIT_ICMS_ST_ESTOQUE_CONV_SAIDA = ''
            self.VL_UNIT_FCP_ICMS_ST_ESTOQUE_CONV_SAIDA = ''
            self.VL_UNIT_ICMS_NA_OPERACAO_CONV_SAIDA = ''
            self.VL_UNIT_ICMS_OP_CONV_SAIDA = ''
            self.VL_UNIT_ICMS_ST_CONV_REST = ''
            self.VL_UNIT_FCP_ST_CONV_REST = ''
            self.VL_UNIT_ICMS_ST_CONV_COMPL = ''
            self.VL_UNIT_FCP_ST_CONV_COMPL = ''
            self.fieldnames = ('REG', 'COD_MOT_REST_COMPL', 'QUANT_CONV', 'UNID', 'COD_MOD_SAIDA',
                               'SERIE_SAIDA', 'ECF_FAB_SAIDA', 'NUM_DOC_SAIDA', 'CHV_DFE_SAIDA',
                               'DT_DOC_SAIDA', 'NUM_ITEM_SAIDA', 'VL_UNIT_CONV_SAIDA',
                               'VL_UNIT_ICMS_OP_ESTOQUE_CONV_SAIDA',
                               'VL_UNIT_ICMS_ST_ESTOQUE_CONV_SAIDA',
                               'VL_UNIT_FCP_ICMS_ST_ESTOQUE_CONV_SAIDA',
                               'VL_UNIT_ICMS_NA_OPERACAO_CONV_SAIDA', 'VL_UNIT_ICMS_OP_CONV_SAIDA',
                               'VL_UNIT_ICMS_ST_CONV_REST', 'VL_UNIT_FCP_ST_CONV_REST',
                               'VL_UNIT_ICMS_ST_CONV_COMPL', 'VL_UNIT_FCP_ST_CONV_COMPL')
            self.formato = self.get_formato()


    class registro_C186(TrackedAttributesClass):
        """
        REGISTRO C186: INFORMAÇÕES COMPLEMENTARES DAS OPERAÇÕES DE DEVOLUÇÃO DE ENTRADAS DE
        MERCADORIAS SUJEITAS À SUBSTITUIÇÃO TRIBUTÁRIA (CÓDIGO 01, 1B, 04 e 55).
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C186, self).__init__()
            self.REG = 'C186'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C100'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_ITEM = ''
            self.COD_ITEM = ''
            self.CST_ICMS = ''
            self.CFOP = ''
            self.COD_MOT_REST_COMPL = ''
            self.QUANT_CONV = ''
            self.UNID = ''
            self.COD_MOD_ENTRADA = ''
            self.SERIE_ENTRADA = ''
            self.NUM_DOC_ENTRADA = ''
            self.CHV_DFE_ENTRADA = ''
            self.DT_DOC_ENTRADA = ''
            self.NUM_ITEM_ENTRADA = ''
            self.VL_UNIT_CONV_ENTRADA = ''
            self.VL_UNIT_ICMS_OP_CONV_ENTRADA = ''
            self.VL_UNIT_BC_ICMS_ST_CONV_ENTRADA = ''
            self.VL_UNIT_ICMS_ST_CONV_ENTRADA = ''
            self.VL_UNIT_FCP_ST_CONV_ENTRADA = ''
            self.fieldnames = ('REG', 'NUM_ITEM', 'COD_ITEM', 'CST_ICMS', 'CFOP',
                               'COD_MOT_REST_COMPL', 'QUANT_CONV', 'UNID', 'COD_MOD_ENTRADA',
                               'SERIE_ENTRADA', 'NUM_DOC_ENTRADA', 'CHV_DFE_ENTRADA',
                               'DT_DOC_ENTRADA', 'NUM_ITEM_ENTRADA', 'VL_UNIT_CONV_ENTRADA',
                               'VL_UNIT_ICMS_OP_CONV_ENTRADA', 'VL_UNIT_BC_ICMS_ST_CONV_ENTRADA',
                               'VL_UNIT_ICMS_ST_CONV_ENTRADA', 'VL_UNIT_FCP_ST_CONV_ENTRADA')
            self.formato = self.get_formato()


class bloco_e(layout_14.bloco_e):
    pass


class bloco_g(layout_14.bloco_g):
    pass
